# relace-mcp-server

[![PyPI](https://img.shields.io/pypi/v/relace-mcp-server)](https://pypi.org/project/relace-mcp-server/)

Official Relace MCP server.

Currently supports [Fast Agentic Search](https://www.relace.ai/blog/fast-agentic-search) via the `relace_search` tool.

## Installation

See [Relace MCP Installation docs](https://docs.relace.ai/docs/fast-agentic-search/mcp-installation) for detailed instructions.

## Releasing

1. [Create a new release](https://github.com/squack-io/relace-mcp-server/releases/new)
2. Enter a new tag (e.g., `v0.1.4`)
3. Publish the release

The workflow will automatically build and publish to PyPI, with the package version derived from the git tag.
